@@ -98,6 +98,10 @@ public abstract class AbstractConnector<T> implements Connector<T, T> {
     protected abstract HttpUriRequest createRequest();
 
     protected void addSessionData(RequestBuilder builder) {
+        String forwardedFor = sessionData.getForwardedFor();
+        if (!StringUtils.isEmpty(forwardedFor)) {
+            builder.addHeader(RequestUtil.HEADER_X_FORWARDED_FOR, forwardedFor);
+        }
         String userAgent = sessionData.getUserAgent();
         if (!StringUtils.isEmpty(userAgent)) {
             builder.addHeader(RequestUtil.HEADER_USER_AGENT, userAgent);
