@@ -139,6 +139,11 @@ public class DefaultConnectorFactory implements ConnectorFactory {
         return new LogoutConnector(configuration, sessionData);
     }
 
+    @Override
+    public ManifestsConnector getManifestsConnector() {
+        return new ManifestsConnector(configuration);
+    }
+
     @Override
     public MoveMailsConnector getMoveMailsConnector(SessionData sessionData, String folderId, List<String> mailIds, String targetFolderId) {
         return new MoveMailsConnector(configuration, sessionData, folderId, mailIds, targetFolderId);
@@ -189,4 +194,9 @@ public class DefaultConnectorFactory implements ConnectorFactory {
         return new VersionConnector(configuration);
     }
 
+    @Override
+    public GetJsLobConnector getGetJsLobConnector(SessionData sessionData, String name) {
+        return new GetJsLobConnector(configuration, sessionData, name);
+    }
+
 }
