@@ -99,8 +99,7 @@ public class AuthenticationEndpoint {
         String userAgent = RequestUtil.getUserAgent(request);
         HostConfiguration configuration = ConfigurationHelper.getConfiguration(request);
         RequestUtil.checkUserAgent(userAgent, configuration);
-        LoginCredentials credentials = getCredentials(authenticationRequestBody)
-                .withRemoteIp(RequestUtil.getRemoteIp(request))
+        LoginCredentials credentials = getCredentials(request, authenticationRequestBody)
                 .withUserAgent(userAgent);
         AuthenticationService authenticationService = authenticationHandler.getAuthenticationService(configuration);
         SessionData sessionData = authenticationService.authenticate(credentials);
@@ -117,7 +116,7 @@ public class AuthenticationEndpoint {
         }
     }
 
-    private LoginCredentials getCredentials(AuthenticationRequestBody requestBody) {
+    private LoginCredentials getCredentials(HttpServletRequest request, AuthenticationRequestBody requestBody) {
         String username = requestBody.getUsername();
         String password = requestBody.getPassword();
         String clientId = requestBody.getClientId();
@@ -127,7 +126,9 @@ public class AuthenticationEndpoint {
         if (StringUtils.isEmpty(password)) {
             throw ApiFacadeException.missingParameter("password");
         }
-        return new LoginCredentials(username, password, clientId);
+        return new LoginCredentials(username, password, clientId)
+                .withForwardedFor(RequestUtil.getForwardedForWithRemoteIp(request))
+                .withRemoteIp(RequestUtil.getRemoteIp(request));
     }
 
     @POST
