@@ -81,7 +81,6 @@ import com.openexchange.mobile.api.facade.models.MailFlags;
 import com.openexchange.mobile.api.facade.models.MailIds;
 import com.openexchange.mobile.api.facade.models.MailThread;
 import com.openexchange.mobile.api.facade.services.MailsService;
-import com.openexchange.mobile.api.facade.utils.AttachmentUtil;
 import com.openexchange.mobile.api.facade.utils.JacksonUtil;
 import com.openexchange.mobile.api.facade.utils.ListUtil;
 import com.openexchange.mobile.api.facade.utils.MapFunction;
@@ -169,7 +168,6 @@ public class MailsEndpoint {
         int mailTeasersDefaultLength = sessionData.getConfiguration().getMailTeasersDefaultLength();
         int maximumTeaserLength = requestBody.getMaximumTeaserLength() != null ? requestBody.getMaximumTeaserLength() : mailTeasersDefaultLength;
         Mail mail = mailsService.getMail(sessionData, folderId, requestBody.getMailId(), maximumTeaserLength);
-        AttachmentUtil.initializeDownloadUrls(folderId, mail);
         MailCto mailCto = new MailCto(mail);
         MailsResponseBody mailsResponseBody = new MailsResponseBody(Collections.singletonList(mailCto));
         return RequestUtil.jsonResponse(mailsResponseBody);
