@@ -53,6 +53,8 @@ import java.util.List;
 
 import com.openexchange.mobile.api.facade.connectors.responses.mtos.AccountMto;
 import com.openexchange.mobile.api.facade.connectors.responses.mtos.UserMto;
+import com.openexchange.mobile.api.facade.utils.ListUtil;
+import com.openexchange.mobile.api.facade.utils.MapFunction;
 import com.openexchange.mobile.api.facade.utils.StringUtils;
 
 import lombok.Data;
@@ -86,7 +88,7 @@ public class Account {
     @NonNull
     private final StandardFolders standardFolders;
 
-    public Account(AccountMto accountMto, UserMto userMto, List<Folder> folders) {
+    public Account(AccountMto accountMto, UserMto userMto, String defaultSendAddress, List<Folder> folders) {
         id = accountMto.getId();
         accountName = accountMto.getAccountName();
         String personalName = accountMto.getPersonalName();
@@ -99,8 +101,14 @@ public class Account {
             firstName = null;
             lastName = null;
         }
-        primaryAddress = accountMto.getPrimaryAddress();
-        aliases = accountMto.getAliases();
+        String accountPrimaryAddress = accountMto.getPrimaryAddress();
+        if (defaultSendAddress == null || accountPrimaryAddress.equals(defaultSendAddress)) {
+            primaryAddress = accountPrimaryAddress;
+            aliases = accountMto.getAliases();
+        } else {
+            primaryAddress = defaultSendAddress;
+            aliases = relaceAddress(accountMto.getAliases(), defaultSendAddress, accountPrimaryAddress);
+        }
         canSend = "0".equals(accountMto.getId()) || !StringUtils.isEmpty(accountMto.getTransportUrl());
         /* Java8: Use with Java 8.
         List<FolderCto> folders = folderMtos.stream()
@@ -148,4 +156,15 @@ public class Account {
         return new StandardFolders(draftsFolder, inboxFolder, sentFolder, spamFolder, trashFolder, archiveFolder);
     }
 
+    private List<String> relaceAddress(List<String> addresses, final String toReplace, final String replacement) {
+        return ListUtil.map(addresses, new MapFunction<String, String>() {
+
+            @Override
+            public String map(String address) {
+                return address.equals(toReplace) ? replacement : address;
+            }
+
+        });
+    }
+
 }
