@@ -56,10 +56,12 @@ public class Config {
 
     private boolean purgeOnDeletion;
 
-    private Integer maxSize;
+    private Long maxSize;
 
-    private Integer maxAttachmentSize;
+    private Long maxAttachmentSize;
 
     private boolean deleteDraftOnTransport;
 
+    private String namespace;
+
 }
