@@ -49,7 +49,6 @@
 
 package com.openexchange.mobile.api.facade.services;
 
-import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
 
@@ -75,6 +74,7 @@ import com.openexchange.mobile.api.facade.connectors.responses.StringResponseMto
 import com.openexchange.mobile.api.facade.connectors.responses.UserResponseMto;
 import com.openexchange.mobile.api.facade.connectors.responses.mtos.AccountMto;
 import com.openexchange.mobile.api.facade.connectors.responses.mtos.ExamineResultMto;
+import com.openexchange.mobile.api.facade.connectors.responses.mtos.FoldersMto;
 import com.openexchange.mobile.api.facade.connectors.responses.mtos.UserMto;
 import com.openexchange.mobile.api.facade.exceptions.ApiFacadeException;
 import com.openexchange.mobile.api.facade.models.Account;
@@ -179,33 +179,19 @@ public class FoldersService {
         boolean includeNonPrivateFolders = sessionData.getConfiguration().isIncludeNonPrivateFolders();
         AllFoldersConnector connector = connectorFactory.getAllFoldersConnector(sessionData, account.getRootFolderId(), language);
         FoldersResponseMto response = connector.execute();
-        List<Folder> folders = new ArrayList<>();
-        if (response.getData() != null) {
-            for (Object[] data : response.getData().getPrivateFolders()) {
-                Folder folder = AllFoldersConnector.map(data);
-                if (isMailFolder(folder, includeNonPrivateFolders)) {
-                    if (folder.getId().equals(account.getArchiveFolderId())) {
-                        folder = folder.withType(Folder.Type.ARCHIVE);
-                    }
-                    folders.add(folder);
-                }
-            }
-        }
-        return folders;
+        FoldersMto data = response.getData();
+        return data != null
+                ? AllFoldersConnector.map(data.getPrivateFolders(), account.getArchiveFolderId(), includeNonPrivateFolders)
+                : Collections.<Folder>emptyList();
     }
 
-    private boolean isMailFolder(Folder folder, boolean includeNonPrivateFolders) {
-        boolean isSubFolder = folder.getParentId() != null && folder.getId().startsWith(folder.getParentId());
-        return isSubFolder && (includeNonPrivateFolders || (!Folder.Type.PUBLIC.equals(folder.getType()) && !Folder.Type.SHARED.equals(folder.getType())));
-    }
-
-    private void examineFolders(ConnectorFactory connectorFactory, SessionData sessionData, List<Folder> folders) {
+    /*private*/ void examineFolders(ConnectorFactory connectorFactory, SessionData sessionData, List<Folder> folders) {
         ExamineMultipleFoldersConnector connector = connectorFactory.getExamineMultipleFoldersConnector(sessionData, folders);
         List<ExamineResponseMto> responses = connector.execute();
 
-        for (int index = 0; index < folders.size(); index++) {
-            Folder folder = folders.get(index);
-            ExamineResponseMto response = responses.get(index);
+        for (int folderIndex = 0, responseIndex = 0; folderIndex < folders.size() && responseIndex < responses.size(); folderIndex++, responseIndex++) {
+            Folder folder = folders.get(folderIndex);
+            ExamineResponseMto response = responses.get(responseIndex);
             ExamineResultMto result = response.getData();
             if (!response.isError() && result != null) {
                 folder.setValidity(result.getValidity());
@@ -213,8 +199,8 @@ public class FoldersService {
                 folder.setTotal(result.getTotal());
                 folder.setUnread(result.getUnread());
             } else {
-                folders.remove(index);
-                index--;
+                folders.remove(folderIndex);
+                folderIndex--;
             }
         }
     }
