@@ -103,7 +103,7 @@ public class RequestUtil {
 
     public static final String HEADER_ACCEPT_LANGUAGE = "Accept-Language";
 
-    public static final String HEADER_FORWARDED_FOR = "X-Forwarded-For";
+    public static final String HEADER_X_FORWARDED_FOR = "X-Forwarded-For";
 
     public static final String HEADER_HOST = "HOST";
 
@@ -146,14 +146,13 @@ public class RequestUtil {
         if (cookies.size() == 0) {
             throw ApiFacadeException.badRequest(ApiFacadeException.Code.MISSING_COOKIES, "Cookies missing");
         }
-        SessionData sessionData = new SessionData(session, cookies);
         String userAgent = getUserAgent(request);
         HostConfiguration hostConfiguration = ConfigurationHelper.getConfiguration(request);
         checkUserAgent(userAgent, hostConfiguration);
-        sessionData = sessionData
+        return new SessionData(session, cookies)
+                .withForwardedFor(getForwardedForWithRemoteIp(request))
                 .withUserAgent(userAgent)
                 .withConfiguration(hostConfiguration);
-        return sessionData;
     }
 
     public String getUserAgent(HttpServletRequest request) {
@@ -217,11 +216,18 @@ public class RequestUtil {
     }
 
     public String getRemoteIp(HttpServletRequest request) {
-        String remoteIp = request.getHeader(HEADER_FORWARDED_FOR);
-        if (remoteIp == null) {
-            remoteIp = request.getRemoteAddr();
+        return request.getRemoteAddr();
+    }
+
+    public String getForwardedForWithRemoteIp(HttpServletRequest request) {
+        String remoteIp = getRemoteIp(request);
+        String forwardedFor = request.getHeader(HEADER_X_FORWARDED_FOR);
+        if (forwardedFor == null) {
+            forwardedFor = remoteIp;
+        } else {
+            forwardedFor += ", " + remoteIp;
         }
-        return remoteIp;
+        return forwardedFor;
     }
 
     public UserAgentInfo parseUserAgent(String userAgent) {
